==> google-cloud-sdk-290.0.1.tgz: google-cloud-sdk/lib/surface/compute/forwarding_rules/__init__.py <==
# -*- coding: utf-8 -*- #
# Copyright 2014 Google LLC. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""Commands for reading and manipulating forwarding rules."""

from __future__ import absolute_import
from __future__ import division
from __future__ import unicode_literals

from googlecloudsdk.calliope import base


class ForwardingRules(base.Group):
  """Read and manipulate traffic forwarding rules to network load balancers."""


ForwardingRules.category = base.LOAD_BALANCING_CATEGORY

ForwardingRules.detailed_help = {
    'DESCRIPTION': """
        Read and manipulate traffic forwarding rules for load balancers,
        protocol forwarding, or Classic Cloud VPN.

        For more information about forwarding rules, see the
        [forwarding rules documentation](https://cloud.google.com/load-balancing/docs/forwarding-rule-concepts).

        See also: [Region forwarding rules API](https://cloud.google.com/compute/docs/reference/rest/v1/forwardingRules)
        and [Global forwarding rules API](https://cloud.google.com/compute/docs/reference/rest/v1/globalForwardingRules).
    """,
}

==> google-cloud-sdk-555.0.0.tgz: google-cloud-sdk/lib/surface/compute/forwarding_rules/__init__.py <==
# -*- coding: utf-8 -*- #
# Copyright 2014 Google LLC. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""Commands for reading and manipulating forwarding rules."""

from __future__ import absolute_import
from __future__ import division
from __future__ import unicode_literals

from googlecloudsdk.calliope import base


@base.UniverseCompatible
@base.ReleaseTracks(
    base.ReleaseTrack.ALPHA, base.ReleaseTrack.BETA, base.ReleaseTrack.GA)
class ForwardingRules(base.Group):
  """Read and manipulate traffic forwarding rules to network load balancers."""


ForwardingRules.category = base.LOAD_BALANCING_CATEGORY

ForwardingRules.detailed_help = {
    'DESCRIPTION': """
        Read and manipulate traffic forwarding rules for load balancers,
        protocol forwarding, or Classic Cloud VPN.

        For more information about forwarding rules, see the
        [forwarding rules documentation](https://cloud.google.com/load-balancing/docs/forwarding-rule-concepts).

        See also: [Region forwarding rules API](https://cloud.google.com/compute/docs/reference/rest/v1/forwardingRules)
        and [Global forwarding rules API](https://cloud.google.com/compute/docs/reference/rest/v1/globalForwardingRules).
    """,
}
